@@ -18,7 +18,7 @@ function generate_testr_results {
     if [ -f .testrepository/0 ]; then
         sudo .tox/functional/bin/testr last --subunit > $WORKSPACE/testrepository.subunit
         sudo mv $WORKSPACE/testrepository.subunit $BASE/logs/testrepository.subunit
-        sudo /usr/os-testr-env/bin/subunit2html $BASE/logs/testrepository.subunit $BASE/logs/testr_results.html
+        sudo .tox/functional/bin/python /usr/local/jenkins/slave_scripts/subunit2html.py $BASE/logs/testrepository.subunit $BASE/logs/testr_results.html
         sudo gzip -9 $BASE/logs/testrepository.subunit
         sudo gzip -9 $BASE/logs/testr_results.html
         sudo chown jenkins:jenkins $BASE/logs/testrepository.subunit.gz $BASE/logs/testr_results.html.gz
@@ -30,22 +30,10 @@ export NOVACLIENT_DIR="$BASE/new/python-novaclient"
 
 sudo chown -R jenkins:stack $NOVACLIENT_DIR
 
-# Get admin credentials
-cd $BASE/new/devstack
-source openrc admin admin
-# pass the appropriate variables via a config file
-CREDS_FILE=$NOVACLIENT_DIR/functional_creds.conf
-cat <<EOF > $CREDS_FILE
-# Credentials for functional testing
-[auth]
-uri = $OS_AUTH_URL
-
-[admin]
-user = $OS_USERNAME
-tenant = $OS_TENANT_NAME
-pass = $OS_PASSWORD
-
-EOF
+# ensure clouds.yaml exists
+mkdir -p ~/.config/openstack
+sudo cp -a ~stack/.config/openstack/clouds.yaml ~/.config/openstack
+sudo chown -R jenkins:stack ~/.config/openstack
 
 # Go to the novaclient dir
 cd $NOVACLIENT_DIR
